@@ -92,42 +92,42 @@ describe 'horizon' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :cache_backend                  => 'horizon.backends.memcached.HorizonMemcached',
-          :cache_options                  => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
-          :cache_server_ip                => '10.0.0.1',
-          :django_session_engine          => 'django.contrib.sessions.backends.cache',
-          :keystone_default_role          => 'SwiftOperator',
-          :keystone_url                   => 'https://keystone.example.com:4682',
-          :ssl_no_verify                  => true,
-          :log_handler                    => 'syslog',
-          :log_level                      => 'DEBUG',
-          :openstack_endpoint_type        => 'internalURL',
-          :secondary_endpoint_type        => 'ANY-VALUE',
-          :django_debug                   => true,
-          :api_result_limit               => 4682,
-          :compress_offline               => false,
-          :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
-          :cinder_options                 => {'enable_backup' => true },
-          :keystone_options               => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
-          :neutron_options                => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
+          :cache_backend                => 'horizon.backends.memcached.HorizonMemcached',
+          :cache_options                => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
+          :cache_server_ip              => '10.0.0.1',
+          :django_session_engine        => 'django.contrib.sessions.backends.cache',
+          :keystone_default_role        => 'SwiftOperator',
+          :keystone_url                 => 'https://keystone.example.com:4682',
+          :ssl_no_verify                => true,
+          :log_handler                  => 'syslog',
+          :log_level                    => 'DEBUG',
+          :openstack_endpoint_type      => 'internalURL',
+          :secondary_endpoint_type      => 'ANY-VALUE',
+          :django_debug                 => true,
+          :api_result_limit             => 4682,
+          :compress_offline             => false,
+          :hypervisor_options           => {'can_set_mount_point' => false, 'can_set_password' => true },
+          :cinder_options               => {'enable_backup' => true },
+          :keystone_options             => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
+          :neutron_options              => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
-          :file_upload_temp_dir           => '/var/spool/horizon',
-          :secure_cookies                 => true,
-          :api_versions                   => {'identity' => 2.0},
-          :keystone_multidomain_support   => true,
-          :keystone_default_domain        => 'domain.tld',
-          :overview_days_range            => 1,
-          :session_timeout                => 1800,
-          :timezone                       => 'Asia/Shanghai',
-          :available_themes               => [
+          :file_upload_temp_dir         => '/var/spool/horizon',
+          :secure_cookies               => true,
+          :api_versions                 => {'identity' => 2.0},
+          :keystone_multidomain_support => true,
+          :keystone_default_domain      => 'domain.tld',
+          :overview_days_range          => 1,
+          :session_timeout              => 1800,
+          :timezone                     => 'Asia/Shanghai',
+          :available_themes             => [
             { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
-          :default_theme                  => 'default',
-          :password_autocomplete          => 'on',
-          :images_panel                   => 'angular',
-          :enable_secure_proxy_ssl_header => true,
+          :default_theme                => 'default',
+          :password_autocomplete        => 'on',
+          :images_panel                 => 'angular',
+          :password_retrieve            => true,
         })
       end
 
@@ -135,7 +135,6 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
           "ALLOWED_HOSTS = ['*', ]",
-          "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           "  'identity': 2.0,",
@@ -173,6 +172,7 @@ describe 'horizon' do
           "    'profile_support': 'cisco',",
           "    'supported_provider_types': ['flat', 'vxlan'],",
           "    'supported_vnic_types': ['*'],",
+          'OPENSTACK_ENABLE_PASSWORD_RETRIEVE = True',
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'API_RESULT_LIMIT = 4682',
@@ -223,6 +223,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
+          :ensure => 'present',
           :tag    => ['openstack']
          )
       }
@@ -413,97 +414,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with websso enabled' do
+    context 'with disable password reveal enabled' do
       before do
         params.merge!({
-                        :websso_enabled => 'True',
-                        :websso_initial_choice => 'acme',
-                        :websso_choices => [
-                          ['oidc', 'OpenID Connect'],
-                          ['saml2', 'Security Assertion Markup Language'],
-                        ],
-                        :websso_idp_mapping => {
-                          'acme_oidc'  => ['acme', 'oidc'],
-                          'acme_saml2' => ['acme', 'saml2'],
-                        }
-                      })
-      end
-      it 'configures websso options' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'WEBSSO_ENABLED = True',
-                                          'WEBSSO_INITIAL_CHOICE = "acme"',
-                                          'WEBSSO_CHOICES = (',
-                                          '    ("credentials", _("Keystone Credentials")),',
-                                          '    ("oidc", _("OpenID Connect")),',
-                                          '    ("saml2", _("Security Assertion Markup Language")),',
-                                          ')',
-                                          'WEBSSO_IDP_MAPPING = {',
-                                          '    "acme_oidc": ("acme", "oidc"),',
-                                          '    "acme_saml2": ("acme", "saml2"),',
-                                          '}',
-                                        ])
-      end
-    end
-
-    context 'with customization_module provided' do
-      before do
-        params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => 'my_project.overrides',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
+          :disable_password_reveal => true
         })
       end
 
-      it 'uses the custom local_settings.py template' do
+      it 'disable_password_reveal is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "    'customization_module': 'my_project.overrides',",
-          "}",
-        ])
-      end
-    end
-
-    context 'with customization_module empty' do
-      before do
-        params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => '',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
-        })
-      end
-
-      it 'uses the custom local_settings.py template' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "}",
+          'HORIZON_CONFIG["disable_password_reveal"] = True',
         ])
       end
     end
@@ -532,7 +452,6 @@ describe 'horizon' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
-          :processorcount => 2,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
